@@ -14,16 +14,14 @@
 #include <QJsonArray>
 #include <QJsonObject>
 #include <QUrlQuery>
-#if APPSTREAM_HAS_SPDX
 #include <AppStreamQt/spdx.h>
-#endif
 
 using namespace AppStreamUtils;
 
 QUrl AppStreamUtils::imageOfKind(const QList<AppStream::Image> &images, AppStream::Image::Kind kind)
 {
     QUrl ret;
-    Q_FOREACH (const AppStream::Image &i, images) {
+    for (const AppStream::Image &i : images) {
         if (i.kind() == kind) {
             ret = i.url();
             break;
@@ -49,7 +47,8 @@ QString AppStreamUtils::changelogToHtml(const AppStream::Component &appdata)
 QPair<QList<QUrl>, QList<QUrl>> AppStreamUtils::fetchScreenshots(const AppStream::Component &appdata)
 {
     QList<QUrl> screenshots, thumbnails;
-    Q_FOREACH (const AppStream::Screenshot &s, appdata.screenshots()) {
+    const auto appdataScreenshots = appdata.screenshots();
+    for (const AppStream::Screenshot &s : appdataScreenshots) {
         const auto images = s.images();
         const QUrl thumbnail = AppStreamUtils::imageOfKind(images, AppStream::Image::KindThumbnail);
         const QUrl plain = AppStreamUtils::imageOfKind(images, AppStream::Image::KindSource);
@@ -64,32 +63,16 @@ QPair<QList<QUrl>, QList<QUrl>> AppStreamUtils::fetchScreenshots(const AppStream
 
 QJsonArray AppStreamUtils::licenses(const AppStream::Component &appdata)
 {
-#if APPSTREAM_HAS_SPDX
     QJsonArray ret;
     const auto licenses = AppStream::SPDX::tokenizeLicense(appdata.projectLicense());
-#if !APPSTREAM_HAS_SPDX_LICENSEURL
-    static const QLatin1String prop("@LicenseRef-proprietary=");
-#endif
     for (const auto &token : licenses) {
         QString license = token;
         license.remove(0, 1); // tokenize prefixes with an @ for some reason
         if (!AppStream::SPDX::isLicenseId(license))
             continue;
-#if APPSTREAM_HAS_SPDX_LICENSEURL
         ret.append(QJsonObject{{QStringLiteral("name"), license}, {QStringLiteral("url"), {AppStream::SPDX::licenseUrl(license)}}});
-#else
-        if (license.startsWith(prop))
-            ret.append(QJsonObject{{QStringLiteral("name"), i18n("Proprietary")}, {QStringLiteral("url"), license.mid(prop.size())}});
-        else
-            ret.append(QJsonObject{{QStringLiteral("name"), license},
-                                   {QStringLiteral("url"),
-                                    {QLatin1String("https://spdx.org/licenses/") + AppStream::SPDX::asSpdxId(license) + QLatin1String(".html#licenseText")}}});
-#endif
     }
     return ret;
-#else
-    return {QJsonObject{{QStringLiteral("name"), appdata.projectLicense()}}};
-#endif
 }
 
 QStringList AppStreamUtils::appstreamIds(const QUrl &appstreamUrl)
@@ -102,3 +85,22 @@ QStringList AppStreamUtils::appstreamIds(const QUrl &appstreamUrl)
     }
     return ret;
 }
+
+QString AppStreamUtils::versionString(const QString &version, const AppStream::Component &appdata)
+{
+    if (version.isEmpty()) {
+        return {};
+    } else {
+        if (appdata.releases().isEmpty())
+            return version;
+
+        auto release = appdata.releases().constFirst();
+        if (release.timestamp().isValid() && version.startsWith(release.version())) {
+            QLocale l;
+            qDebug() << "versionversion" << version << release.version();
+            return i18n("%1, released on %2", version, l.toString(release.timestamp().date(), QLocale::ShortFormat));
+        } else {
+            return version;
+        }
+    }
+}
