@@ -7,19 +7,19 @@
 #ifndef KNSRESOURCE_H
 #define KNSRESOURCE_H
 
-#include <resources/AbstractResource.h>
 #include <KNSCore/EntryInternal>
 #include <QPointer>
 #include <attica/content.h>
+#include <resources/AbstractResource.h>
 
 #include "discovercommon_export.h"
 
 class KNSBackend;
 class DISCOVERCOMMON_EXPORT KNSResource : public AbstractResource
 {
-Q_OBJECT
+    Q_OBJECT
 public:
-    explicit KNSResource(const KNSCore::EntryInternal & c, QStringList categories, KNSBackend* parent);
+    explicit KNSResource(const KNSCore::EntryInternal &c, QStringList categories, KNSBackend *parent);
     ~KNSResource() override;
 
     AbstractResource::State state() override;
@@ -31,7 +31,10 @@ public:
     QUrl homepage() override;
     QJsonArray licenses() override;
     QString longDescription() override;
-    QList<PackageState> addonsInformation() override { return QList<PackageState>(); }
+    QList<PackageState> addonsInformation() override
+    {
+        return QList<PackageState>();
+    }
     QString availableVersion() const override;
     QString installedVersion() const override;
     QString origin() const override;
@@ -40,12 +43,15 @@ public:
     int size() override;
     void fetchChangelog() override;
     QStringList extends() const override;
-    AbstractResource::Type type() const override { return Addon; }
+    AbstractResource::Type type() const override
+    {
+        return Addon;
+    }
     QString author() const override;
 
-    KNSBackend* knsBackend() const;
+    KNSBackend *knsBackend() const;
 
-    void setEntry(const KNSCore::EntryInternal& entry);
+    void setEntry(const KNSCore::EntryInternal &entry);
     KNSCore::EntryInternal entry() const;
 
     bool canExecute() const override;
@@ -53,12 +59,15 @@ public:
 
     QUrl url() const override;
     QString executeLabel() const override;
-    QString sourceIcon() const override { return QStringLiteral("get-hot-new-stuff"); }
+    QString sourceIcon() const override
+    {
+        return QStringLiteral("get-hot-new-stuff");
+    }
     QDate releaseDate() const override;
     QVector<int> linkIds() const;
     QUrl donationURL() override;
 
-    Rating* ratingInstance();
+    Rating *ratingInstance();
 
 private:
     const QStringList m_categories;
