@@ -11,11 +11,11 @@
 #include <resources/AbstractResourcesBackend.h>
 
 #include "rpmostree1.h"
+#include <QDBusPendingReply>
 #include <QMetaType>
 #include <QProcess>
 #include <QSharedPointer>
 #include <QThreadPool>
-#include <QtDBus/QDBusPendingReply>
 
 class RpmOstreeReviewsBackend;
 class OdrsReviewsBackend;
