@@ -15,6 +15,7 @@
 #include <QDBusPendingCall>
 #include <QDebug>
 #include <QNetworkConfigurationManager>
+#include <QProcess>
 
 #include <KIO/ApplicationLauncherJob>
 #include <KIO/CommandLauncherJob>
@@ -25,11 +26,18 @@
 DiscoverNotifier::DiscoverNotifier(QObject *parent)
     : QObject(parent)
 {
+    m_settings = new UpdatesSettings(this);
+    m_settingsWatcher = KConfigWatcher::create(m_settings->sharedConfig());
+    refreshUnattended();
+    connect(m_settingsWatcher.data(), &KConfigWatcher::configChanged, this, &DiscoverNotifier::refreshUnattended);
+
     m_backends = BackendNotifierFactory().allBackends();
-    foreach (BackendNotifierModule *module, m_backends) {
+    for (BackendNotifierModule *module : qAsConst(m_backends)) {
         connect(module, &BackendNotifierModule::foundUpdates, this, &DiscoverNotifier::updateStatusNotifier);
         connect(module, &BackendNotifierModule::needsRebootChanged, this, [this]() {
-            if (!m_needsReboot) {
+            // If we are using offline updates, there is no need to badger the user to
+            // reboot since it is safe to continue using the system in its current state
+            if (!m_needsReboot && !m_settings->useUnattendedUpdates()) {
                 m_needsReboot = true;
                 showRebootNotification();
                 Q_EMIT stateChanged();
@@ -46,18 +54,14 @@ DiscoverNotifier::DiscoverNotifier(QObject *parent)
 
     // Only fetch updates after the system is comfortably booted
     QTimer::singleShot(20000, this, &DiscoverNotifier::recheckSystemUpdateNeeded);
-
-    m_settings = new UpdatesSettings(this);
-    m_settingsWatcher = KConfigWatcher::create(m_settings->sharedConfig());
-    refreshUnattended();
-    connect(m_settingsWatcher.data(), &KConfigWatcher::configChanged, this, &DiscoverNotifier::refreshUnattended);
 }
 
 DiscoverNotifier::~DiscoverNotifier() = default;
 
-void DiscoverNotifier::showDiscover()
+void DiscoverNotifier::showDiscover(const QString &xdgActivationToken)
 {
     auto *job = new KIO::ApplicationLauncherJob(KService::serviceByDesktopName(QStringLiteral("org.kde.discover")));
+    job->setStartupId(xdgActivationToken.toUtf8());
     job->setUiDelegate(new KNotificationJobUiDelegate(KJobUiDelegate::AutoErrorHandlingEnabled));
     job->start();
 
@@ -66,11 +70,12 @@ void DiscoverNotifier::showDiscover()
     }
 }
 
-void DiscoverNotifier::showDiscoverUpdates()
+void DiscoverNotifier::showDiscoverUpdates(const QString &xdgActivationToken)
 {
     auto *job = new KIO::CommandLauncherJob(QStringLiteral("plasma-discover"), {QStringLiteral("--mode"), QStringLiteral("update")});
     job->setUiDelegate(new KNotificationJobUiDelegate(KJobUiDelegate::AutoErrorHandlingEnabled));
     job->setDesktopName(QStringLiteral("org.kde.discover"));
+    job->setStartupId(xdgActivationToken.toUtf8());
     job->start();
 
     if (m_updatesAvailableNotification) {
@@ -99,7 +104,9 @@ void DiscoverNotifier::showUpdatesNotification()
     const QString name = i18n("View Updates");
     m_updatesAvailableNotification->setDefaultAction(name);
     m_updatesAvailableNotification->setActions({name});
-    connect(m_updatesAvailableNotification, QOverload<unsigned int>::of(&KNotification::activated), this, &DiscoverNotifier::showDiscoverUpdates);
+    connect(m_updatesAvailableNotification, QOverload<unsigned int>::of(&KNotification::activated), this, [this] {
+        showDiscoverUpdates({});
+    });
 }
 
 void DiscoverNotifier::updateStatusNotifier()
@@ -194,7 +201,7 @@ QString DiscoverNotifier::message() const
     case Offline:
         return i18n("Offline");
     case Busy:
-        return i18n("Applying unattended updates...");
+        return i18n("Applying unattended updates…");
     }
     return QString();
 }
@@ -209,7 +216,7 @@ void DiscoverNotifier::recheckSystemUpdateNeeded()
         }
     }
 
-    foreach (BackendNotifierModule *module, m_backends)
+    for (BackendNotifierModule *module : qAsConst(m_backends))
         module->recheckSystemUpdateNeeded();
 
     refreshUnattended();
@@ -225,12 +232,16 @@ QStringList DiscoverNotifier::loadedModules() const
 
 void DiscoverNotifier::showRebootNotification()
 {
-    KNotification *notification = new KNotification(QStringLiteral("notification"), KNotification::Persistent | KNotification::DefaultEvent);
-    notification->setIconName(QStringLiteral("system-software-update"));
-    notification->setActions(QStringList{i18nc("@action:button", "Restart")});
-    notification->setTitle(i18n("Restart is required"));
-    notification->setText(i18n("The system needs to be restarted for the updates to take effect."));
+    KNotification *notification = KNotification::event(QStringLiteral("UpdateRestart"),
+                                                       i18n("Restart is required"),
+                                                       i18n("The system needs to be restarted for the updates to take effect."),
+                                                       QStringLiteral("system-software-update"),
+                                                       nullptr,
+                                                       KNotification::Persistent | KNotification::DefaultEvent,
+                                                       QStringLiteral("discoverabstractnotifier"));
 
+    notification->setActions(QStringList{i18nc("@action:button", "Restart")});
+    notification->setDefaultAction(notification->actions().constFirst());
     connect(notification, &KNotification::action1Activated, this, &DiscoverNotifier::reboot);
 
     notification->sendEvent();
